orca r3935 - trunk/test/keystrokes/firefox



Author: joanied
Date: Thu May 29 02:52:03 2008
New Revision: 3935
URL: http://svn.gnome.org/viewvc/orca?rev=3935&view=rev

Log:
Updated regression test to reflect the new Home/End behavior.


Modified:
   trunk/test/keystrokes/firefox/line_nav_bugzilla_search.py

Modified: trunk/test/keystrokes/firefox/line_nav_bugzilla_search.py
==============================================================================
--- trunk/test/keystrokes/firefox/line_nav_bugzilla_search.py	(original)
+++ trunk/test/keystrokes/firefox/line_nav_bugzilla_search.py	Thu May 29 02:52:03 2008
@@ -28,8 +28,13 @@
 sequence.append(PauseAction(1000))
 
 ########################################################################
 # Press Control+Home to move to the top.
 #
+sequence.append(KeyPressAction(0, None, "KP_Insert"))
+sequence.append(KeyComboAction("Right"))
+sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
+
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Control>Home"))
 sequence.append(utils.AssertPresentationAction(
@@ -37,7 +42,6 @@
     ["BRAILLE LINE:  'Home Link Image Bugzilla'",
      "     VISIBLE:  'Home Link Image Bugzilla', cursor=1",
      "SPEECH OUTPUT: 'Home link image Bugzilla'"]))
-sequence.append(PauseAction(1000))
 
 ########################################################################
 # Down Arrow.
@@ -28,8 +28,13 @@
 
 ########################################################################
-# Press Control+Home to move to the top.
+# Press Orca+Right to get out of the focused entry, then Control+Home
+# to move to the top.
 #



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]